#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
@time   : 2021/1/8 16:23
@file   : logger.py
@author : nbyue
@desc   : 
@exec   : /bin/python3 logger.py
@wiki
"""
import logging
from logging.handlers import RotatingFileHandler


def log2file(log_file):
    """
    :param log_file:
    :return:
    """
    logger = logging.getLogger(__name__)
    logger.setLevel(level=logging.INFO)
    # 定义handler的输出格式
    fmt = logging.Formatter(
        "%(asctime)s - [line:%(lineno)d] - %(levelname)s: %(message)s")
    handler = RotatingFileHandler(
        filename=log_file, mode='a', maxBytes=10 * 1024 * 1024, backupCount=2)
    handler.setLevel(logging.INFO)
    handler.setFormatter(fmt)
    logger.addHandler(handler)
    return logger



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@time   : 2020/8/21 16:04
@file   : drobot.py
@author :
@desc   : 此脚本是用py3执行
@exec   :
"""
import json
import requests
import time
import hmac
import hashlib
import base64
import urllib.parse


class SendMessage():
    def __init__(self, secret, token):
        self.token = token
        self.secret = secret

    def ding_sign(self):
        """
        钉钉安全：加签
        :return:
        """
        timestamp = str(round(time.time() * 1000))
        secret_enc = self.secret.encode('utf-8')
        string_to_sign = '{}\n{}'.format(timestamp, self.secret)
        string_to_sign_enc = string_to_sign.encode('utf-8')
        hmac_code = hmac.new(secret_enc, string_to_sign_enc, digestmod=hashlib.sha256).digest()
        sign = urllib.parse.quote_plus(base64.b64encode(hmac_code))
        return timestamp, sign

    def send_message(self, msg_style):
        """
        传入消息格式及内容
        :param msg_style:  消息格式
        :return:
        """
        ts, sign = self.ding_sign()
        url = 'https://oapi.dingtalk.com/robot/send?access_token={token}&timestamp={time}&sign={sign}' \
            .format(token=self.token, time=ts, sign=sign)

        pagrem = msg_style

        headers = {
            'Content-Type': 'application/json'
        }
        requests.post(url, data=json.dumps(pagrem), headers=headers)

    def style_actioncard(self, btns, title, content, atone="", isatall=False):
        pagrem = {
            "msgtype": "actionCard",
            "actionCard": {
                "title": title,
                "text": content,
                "btnOrientation": "0",
                "btns": btns
            },
            "at": {
                "atMobiles": [
                    atone  # 需要填写自己的手机号，钉钉通过手机号@对应人
                ],
                "isAtAll": isatall  # 是否@所有人，默认否
            }
        }
        return pagrem

    def style_text(self, content, atone="", isatall=False):
        pagrem = {
            "msgtype": "text",
            "text": {
                "content": content
            },
            "at": {
                "atMobiles": [
                    atone
                ],
                "isAtAll": isatall
            }
        }
        return pagrem

    def style_md(self, title, content, atone="", isatall=False):
        """
        :param title:
        :param content:
        :param atone:
        :param isatall:
        :return:
        """
        pagrem = {
            "msgtype": "markdown",
            "markdown": {
                "title": title,
                "text": content
            },
            "at": {
                "atMobiles": [
                    atone
                ],
                "isAtAll": isatall
            }
        }
        return pagrem



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
@time   : 2020/9/21 16:39
@file   : mysql.py
@author : 
@desc   : 
@exec   : 
"""

import pymysql
from pymysql.cursors import DictCursor


class Conn(object):
    """定义一个 MySQL 操作类"""

    def __init__(self, **config):
        """初始化数据库信息并创建数据库连接"""
        try:
            self.conn = pymysql.connect(**config)
        except Exception as e:
            exit(e)
        try:
            # 测试mysql是否通
            self.cur = self.conn.cursor()
        except Exception as e:
            exit(e)

    def select(self, select_sql, return_type=None):
        """执行select, show 类查询，有返回值"""
        try:
            if return_type in ("Dict", "dict", "d", "D"):
                self.cur = self.conn.cursor(DictCursor)
            self.cur.execute(select_sql)
            rt_tuple = self.cur.fetchall()
            return rt_tuple
        except Exception as e:
            print(e)
            return b''

    def exec(self, sql):
        """执行非查询类语句"""
        try:
            self.cur.execute(sql)
            self.conn.commit()
        except Exception as e:
            self.conn.rollback()
            print(e)

    def close(self):
        self.cur.close()
        self.conn.close()



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
'''
@time   : 2020/10/20 19:13
@file   : shell.py
@author : 
@desc   : 
@exec   : 
'''
import subprocess


def run(exec_cmd, is_exit=0):
    """
    传入shell脚本，默认执行报错不退出当前执行脚本。
    :param exec_cmd:
    :param is_exit:
    :return:
    """
    r_shell = subprocess.Popen(
        exec_cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    stdout, stderr = r_shell.communicate()
    r_code = r_shell.returncode
    if r_code == 0:
        return stdout, r_code
    else:
        err_msg = 'exit\nerror info:{err}\nexec shell failed: {cmd}'.format(
            err=stderr, cmd=exec_cmd)
        if is_exit:
            exit(err_msg)
        else:
            return err_msg, r_code



from setuptools import setup, find_packages


with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='amhhandler',       # 包名
    version='1.2.2',         # 版本号
    description='An even better way to work with Python.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='nbyue',
    author_email='20671413@163.com',
    url='https://gitee.com/nbyue/amh-handler',
    license="MIT",    # 开源协议
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    python_requires=">=3.6",
    install_requires=['pymysql', 'requests'],
)
